Stan Math Library: stan/math/rev/core/dvd_vari.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

dvd_vari.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_DVD_VARI_HPP
2 #define STAN_MATH_REV_CORE_DVD_VARI_HPP
3
4 #include <stan/math/rev/core/vari.hpp>
5
6 namespace stan {
7 namespace math {
8
9 class op_dvd_vari : public vari {
10 protected:
11 double ad_;
12 vari* bvi_;
13 double cd_;
14 public:
15 op_dvd_vari(double f, double a, vari* bvi, double c) :
16 vari(f),
17 ad_(a),
18 bvi_(bvi),
19 cd_(c) {
20 }
21 };
22
23 }
24 }
25 #endif
vari.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::op_dvd_vari::bvi_
vari * bvi_
Definition: dvd_vari.hpp:12
stan::math::vari
The variable implementation base class.
Definition: vari.hpp:30
stan::math::op_dvd_vari::op_dvd_vari
op_dvd_vari(double f, double a, vari *bvi, double c)
Definition: dvd_vari.hpp:15
stan::math::op_dvd_vari::ad_
double ad_
Definition: dvd_vari.hpp:11
stan::math::op_dvd_vari::cd_
double cd_
Definition: dvd_vari.hpp:13
stan::math::op_dvd_vari
Definition: dvd_vari.hpp:9

[ Stan Home Page ] © 2011–2016, Stan Development Team.